@@ -7,6 +7,7 @@
 #' @param hist_rng numeric vector, if historic range is not specified then the min/max values of the data set will be used.
 #' @param target_yr numeric, the target year that should be compared against the historic range. If target year is not specified then dot will not be plotted
 #' @param criteria numeric, a numeric criteria that will be plotted as a horizontal line
+#' @param free_y logical, should the y-axis be free? Defaults to \code{FALSE}. If \code{FALSE}, defaults to zero, unless negative values are present. If \code{TRUE}, y-axis limits are selected by \code{ggplot}
 #' @param log_trans logical, should y-axis be log? Defaults to \code{FALSE}
 #' @param converted logical, were the units converted from the original units used by CDMO? Defaults to \code{FALSE}. See \code{y_labeler} for details.
 #' @param criteria_lab chr, label for the threshold criteria defined in \code{criteria}. Defaults to "WQ Threshold"
@@ -20,7 +21,7 @@
 #' @importFrom magrittr "%>%"
 #' @importFrom lubridate  year floor_date yday
 #' @importFrom rlang .data
-#' @importFrom scales comma
+#' @importFrom scales format_format pretty_breaks
 #' @importFrom tidyr complete
 #'
 #' @export
@@ -46,7 +47,7 @@
 #' y <- historical_daily_range(dat, param = 'do_mgl', target_yr = 2012)
 #' }
 #'
-#' \dontrun{
+#' \donttest{
 ## get data, prep
 #' data(apacpwq)
 #' dat <- apacpwq
@@ -66,8 +67,6 @@ historical_daily_range <- function(swmpr_in, ...) UseMethod('historical_daily_ra
 
 #' @rdname historical_daily_range
 #'
-#' @concept analyze
-#'
 #' @export
 #'
 #' @method historical_daily_range swmpr
@@ -77,6 +76,7 @@ historical_daily_range.swmpr <- function(swmpr_in
                                    , hist_rng = NULL
                                    , target_yr = NULL
                                    , criteria = NULL
+                                   , free_y = FALSE
                                    , log_trans = FALSE
                                    , converted = FALSE
                                    , criteria_lab = 'WQ Threshold'
@@ -165,15 +165,15 @@ historical_daily_range.swmpr <- function(swmpr_in
   # Determine average min/max/mean for each julian day (for all years together)
   dat_hist_avg <- dat_all %>%
     dplyr::group_by(!! jd) %>%
-    dplyr::summarise(mean = mean(!! avg, na.rm = T)
-                     , min = mean(!!  mini, na.rm = T)
-                     , max = mean(!! maxi, na.rm = T))
+    dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
+                     , min = mean(!!  mini, na.rm = TRUE)
+                     , max = mean(!! maxi, na.rm = TRUE))
 
   dat_hist_obs <- dat_all %>%
     dplyr::group_by(!! jd) %>%
-    dplyr::summarise(mean = mean(!! avg, na.rm = T)
-                     , min = min(!!  mini, na.rm = T)
-                     , max = max(!! maxi, na.rm = T))
+    dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
+                     , min = min(!!  mini, na.rm = TRUE)
+                     , max = max(!! maxi, na.rm = TRUE))
 
   # account for missing julian days
   if(length(dat_yr[1, ] < 365)){
@@ -182,14 +182,9 @@ historical_daily_range.swmpr <- function(swmpr_in
   }
 
   if(plot){
-    # Set the plot range
-    mx <- max(dat_hist_obs$max, na.rm = T)
-    mx <- ceiling(mx)
-    # mn <- ifelse(log_trans, ifelse(substr(station, 6, nchar(station)) == 'nut', 0.001, 0.1), 0)
-
     # assign a minimum of zero unles there are values < 0
-    mn <- ifelse(min(dat_hist_obs$min, na.rm = T) < min(dat_hist_avg$min, na.rm = T)
-                 , min(dat_hist_obs$min, na.rm = T), min(dat_hist_avg$min, na.rm = T))
+    mn <- ifelse(min(dat_hist_obs$min, na.rm = TRUE) < min(dat_hist_avg$min, na.rm = TRUE)
+                 , min(dat_hist_obs$min, na.rm = TRUE), min(dat_hist_avg$min, na.rm = TRUE))
     mn <- ifelse(mn < 0 , min(pretty(mn)), 0)
     mn <- ifelse(log_trans, ifelse(substr(station, 6, nchar(station)) == 'nut', 0.001, 0.1), mn)
 
@@ -213,27 +208,28 @@ historical_daily_range.swmpr <- function(swmpr_in
       theme_bw() +
       theme(legend.position = 'top', legend.direction = 'horizontal')
 
-    # add a log transformed access if log_trans = T
+    # add a log transformed access if log_trans == TRUE
+    ## allow y-axis to be free if free_y == TRUE
     if(!log_trans) {
+      plt <- plt +
+        scale_y_continuous(labels = format_format(digits = 2, big.mark = ",", decimal.mark = ".", scientific = FALSE)
+                           , breaks = pretty_breaks(n = 8))
 
-      plt <- plt + scale_y_continuous(limits = c(mn, mx), trans = y_trans, labels = scales::comma)
+      if(!free_y){plt <- plt + expand_limits(y = mn)}
 
     } else {
+      plt <- plt +
+        scale_y_continuous(trans = y_trans
+                                , labels = format_format(digits = 2, big.mark = ",", decimal.mark = ".", scientific = FALSE)
+                                , breaks = pretty_breaks(n = 8))
 
-      mx_log <- 10^(ceiling(log10(mx)))
-
-      mag_lo <- nchar(mn) - 2
-      mag_hi <- nchar(mx_log) - 1
-
-      brks <- 10^(-mag_lo:mag_hi)
-
-      plt <- plt + scale_y_continuous(limits = c(mn, mx_log), breaks = brks, trans = y_trans, labels = scales::comma)
+      if(!free_y) {plt <- plt + expand_limits(y = mn)}
     }
 
     # Adjust legend order
     plt <-
       plt +
-      guides(fill = guide_legend(override.aes = list(linetype = 0), order = 2, reverse = T)
+      guides(fill = guide_legend(override.aes = list(linetype = 0), order = 2, reverse = TRUE)
              , color = guide_legend(override.aes = list(color = 'steelblue3'), order = 1))
 
 
@@ -260,19 +256,19 @@ historical_daily_range.swmpr <- function(swmpr_in
             , legend.key.width = unit(0.5, 'cm')) +
       theme(legend.text = element_text(size = 10)
             , legend.text.align = 0.5) +
-      theme(legend.spacing.x = unit(-6, 'pt'))
+      theme(legend.spacing.x = unit(3, 'pt'))
 
     # Add criteria line if specified
     if(!is.null(criteria)) {
 
       plt <- plt +
         geom_hline(aes(yintercept = criteria, linetype = factor(criteria_lab))
-                   , color = 'red', show.legend = T) +
+                   , color = 'red', show.legend = TRUE) +
         scale_linetype_manual('', values = c('longdash'))
 
       plt <-
         plt +
-        guides(fill = guide_legend(override.aes = list(linetype = 0), order = 2, reverse = T)
+        guides(fill = guide_legend(override.aes = list(linetype = 0), order = 2, reverse = TRUE)
                , color = guide_legend(override.aes = list(color = 'steelblue3'), order = 1)
                , linetype = guide_legend(override.aes = list(color = 'red'), order = 3))
     }
