@@ -7,6 +7,7 @@
 #' @param hist_rng num, years to include in the plot. This variable can either be one year (e.g., \code{hist_rng = 2012}), or two years (e.g. \code{hist_rng = c(2012, 2016)}) , If range is not specified then the entire data set will be used.
 #' @param target_yr num, year of interest for plotting. If not specified, the entire data set will be plotted.
 #' @param percentiles num, percentiles to calculate (maximum: 2). Defaults to 5th and 95th percentiles.
+#' @param free_y logical, should the y-axis be free? Defaults to \code{FALSE}. If \code{FALSE}, defaults to zero, unless negative values are present. If \code{TRUE}, y-axis limits are selected by \code{ggplot}
 #' @param by_month logical. should percentiles be calculated on a monthly basis? Defaults to \code{FALSE}
 #' @param log_trans logical, should y-axis be log? Defaults to \code{FALSE}
 #' @param converted logical, were the units converted from the original units used by CDMO? Defaults to \code{FALSE}. See \code{y_labeler} for details.
@@ -18,7 +19,7 @@
 #' @importFrom dplyr filter group_by left_join summarise
 #' @importFrom magrittr "%>%"
 #' @importFrom lubridate  ymd_hms month year
-#' @importFrom scales comma
+#' @importFrom scales format_format
 #' @importFrom stats quantile
 #'
 #' @export
@@ -36,7 +37,7 @@
 #' @return Returns a \code{\link[ggplot2]{ggplot}} object
 #'
 #' @references
-#' United States Environmental Protection Agency (USEPA). 2016. "National Coastal Condition Assessment 2010". EPA 841-R-15-006.
+#' United States Environmental Protection Agency (USEPA). 2015. "National Coastal Condition Assessment 2010". EPA 841-R-15-006.
 #' https://cfpub.epa.gov/si/si_public_record_Report.cfm?dirEntryId=327030
 #'
 #' @seealso \code{\link[ggplot2]{ggplot}}
@@ -49,7 +50,7 @@
 #'   threshold_percentile_plot(dat_wq, param = 'do_mgl'
 #'   , hist_rng = c(2007, 2014), by_month = FALSE)
 #'
-#' \dontrun{
+#' \donttest{
 #' y <-
 #'   threshold_percentile_plot(dat_wq, param = 'do_mgl', percentiles = c(0.95)
 #'   , hist_rng = c(2007, 2014), target_yr = 2014, by_month = FALSE)
@@ -80,8 +81,6 @@ threshold_percentile_plot <- function(swmpr_in, ...) UseMethod('threshold_percen
 
 #' @rdname threshold_percentile_plot
 #'
-#' @concept analyze
-#'
 #' @export
 #'
 #' @method threshold_percentile_plot swmpr
@@ -91,6 +90,7 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
                                          , hist_rng = NULL
                                          , target_yr = NULL
                                          , percentiles = c(0.05, 0.95)
+                                         , free_y = FALSE
                                          , by_month = FALSE
                                          , log_trans = FALSE
                                          , converted = FALSE
@@ -164,12 +164,12 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
   if(length(percentiles) > 1) {
     bars <- dat_subset %>%
       group_by(!! grp) %>%
-      summarise(perc_hi = quantile(!! parm, probs = max(percentiles), na.rm = T)
-                , perc_lo = quantile(!! parm, probs = min(percentiles), na.rm = T))
+      summarise(perc_hi = quantile(!! parm, probs = max(percentiles), na.rm = TRUE)
+                , perc_lo = quantile(!! parm, probs = min(percentiles), na.rm = TRUE))
   } else {
     bars <- dat_subset %>%
       group_by(!! grp) %>%
-      summarise(perc_hi = quantile(!! parm, probs = percentiles, na.rm = T))
+      summarise(perc_hi = quantile(!! parm, probs = percentiles, na.rm = TRUE))
   }
 
   if(!is.null(target_yr)){
@@ -182,7 +182,7 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
   yr_ct <- mx_yr - mn_yr + 1
 
   # add dummy data to bars
-  dummy <- data.frame(month = rep(c(1:12), yr_ct), year = rep(c(mn_yr:mx_yr), each = 12), dummy = -999, stringsAsFactors = F)
+  dummy <- data.frame(month = rep(c(1:12), yr_ct), year = rep(c(mn_yr:mx_yr), each = 12), dummy = -999, stringsAsFactors = FALSE)
   dummy[nrow(dummy) + 1 , ] <- c(1, max(dummy$year) + 1, -999)
 
   bar_plt <- left_join(dummy, bars)
@@ -201,15 +201,15 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
   brks <- ifelse(is.null(target_yr), set_date_breaks(hist_rng), set_date_breaks(target_yr))
   lab_brks <- ifelse(is.null(target_yr), set_date_break_labs(hist_rng), set_date_break_labs(target_yr))
 
-  mx <- ifelse(max(dat_subset[ , 2], na.rm = T) > max(bars$perc_hi), max(dat_subset[ , 2], na.rm = T), max(bars$perc_hi))
+  mx <- ifelse(max(dat_subset[ , 2], na.rm = TRUE) > max(bars$perc_hi), max(dat_subset[ , 2], na.rm = TRUE), max(bars$perc_hi))
   mx <- ifelse(data_type == 'nut' && param != 'chla_n', ceiling(mx/0.01) * 0.01, ceiling(mx))
 
   if(length(percentiles) > 1) {
-    mn <- ifelse(min(dat_subset[ , 2], na.rm = T) < min(bars$perc_lo), min(dat_subset[ , 2], na.rm = T), min(bars$perc_lo))
-    mn <- ifelse(data_type == 'nut', 0, ifelse(mn < 0, floor(mn), ceiling(mn)))
+    mn <- ifelse(min(dat_subset[ , 2], na.rm = TRUE) < min(bars$perc_lo), min(dat_subset[ , 2], na.rm = TRUE), min(bars$perc_lo))
+    mn <- ifelse(data_type == 'nut', 0, floor(mn))
   } else {
-    mn <- ifelse(min(dat_subset[ , 2], na.rm = T) < min(bars$perc_hi), min(dat_subset[ , 2], na.rm = T), min(bars$perc_hi)) #note: perc_lo DNE when percentiles < 2
-    mn <- ifelse(data_type == 'nut', 0, ifelse(mn < 0, floor(mn), ceiling(mn)))
+    mn <- ifelse(min(dat_subset[ , 2], na.rm = TRUE) < min(bars$perc_hi), min(dat_subset[ , 2], na.rm = TRUE), min(bars$perc_hi)) #note: perc_lo DNE when percentiles < 2
+    mn <- ifelse(data_type == 'nut', 0, ceiling(mx))
   }
   mn <- ifelse(log_trans, ifelse(substr(station, 6, nchar(station)) == 'nut', 0.001, 0.1), mn)
 
@@ -219,11 +219,14 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
     geom_line(lwd = 1) +
     scale_x_datetime(date_breaks = brks, date_labels = lab_brks)
 
-  # add a log transformed access if log_trans = T
+  # add a log transformed access if log_trans = TRUE
   if(!log_trans) {
 
     plt <- plt +
-      scale_y_continuous(limits = c(mn, mx), trans = y_trans, labels = scales::comma)
+      scale_y_continuous(labels = format_format(digits = 2, big.mark = ",", decimal.mark = ".", scientific = FALSE)
+                         , breaks = pretty_breaks(n = 8))
+
+    if(!free_y){plt <- plt + expand_limits(y = mn)}
 
   } else {
 
@@ -235,7 +238,10 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
     brks <- 10^(-mag_lo:mag_hi)
 
     plt <- plt +
-      scale_y_continuous(limits = c(mn, mx_log), breaks = brks, trans = y_trans, labels = scales::comma)
+      scale_y_continuous(breaks = brks, trans = y_trans
+                         , labels = format_format(digits = 2, big.mark = ",", decimal.mark = ".", scientific = FALSE))
+
+    if(!free_y) {plt <- plt + expand_limits(y = mn)}
   }
 
   if(length(percentiles) > 1) {
@@ -259,7 +265,7 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
       plt +
       geom_line(data = bar_plt, aes_(x = dt, y = p_hi, color = lab_perc)
                 , lwd = 1
-                , inherit.aes = F)
+                , inherit.aes = FALSE)
   }
 
 
@@ -299,12 +305,12 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
           , legend.key.width = unit(0.5, 'cm')) +
     theme(legend.text = element_text(size = 10)
           , legend.text.align = 0.5) +
-    theme(legend.spacing.x = unit(-6, 'pt'))
+    theme(legend.spacing.x = unit(3, 'pt'))
 
   plt <-
     plt +
     guides(fill = guide_legend(order = 1)
-           , color = guide_legend(order = 2, reverse = T))
+           , color = guide_legend(order = 2, reverse = TRUE))
 
   # add plot title if specified
   if(plot_title) {
